package com.srs.dormitory.service;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.core.page.TableDataInfo;
import com.srs.dormitory.domain.DmsApprovalProcess;
import com.srs.dormitory.domain.DmsTransferApplication;
import com.srs.dormitory.domain.Dto.DmsAuditDto;

/**
 * 宿舍管理审核Service接口
 *
 * @author srs
 * @date 2023-10-31
 */
public interface IDmsApprovalProcessService extends IService<DmsApprovalProcess> {
    /**
     * 查询宿舍管理审核
     *
     * @param id 宿舍管理审核主键
     * @return 宿舍管理审核
     */
    public DmsApprovalProcess selectDmsApprovalProcessById(Long id);

    /**
     * 查询宿舍管理审核列表
     *
     * @param dmsApprovalProcess 宿舍管理审核
     * @return 宿舍管理审核集合
     */
    List<DmsApprovalProcess> selectDmsApprovalProcessList(DmsApprovalProcess dmsApprovalProcess);

    /**
     * 新增宿舍管理审核
     *
     * @param dmsApprovalProcess 宿舍管理审核
     * @return 结果
     */
    int insertDmsApprovalProcess(DmsApprovalProcess dmsApprovalProcess);

    /**
     * 修改宿舍管理审核
     *
     * @param dmsApprovalProcess 宿舍管理审核
     * @return 结果
     */
    int updateDmsApprovalProcess(DmsApprovalProcess dmsApprovalProcess);

    /**
     * 批量删除宿舍管理审核
     *
     * @param ids 需要删除的宿舍管理审核主键集合
     * @return 结果
     */
    int deleteDmsApprovalProcessByIds(Long[] ids);

    /**
     * 删除宿舍管理审核信息
     *
     * @param id 宿舍管理审核主键
     * @return 结果
     */
    int deleteDmsApprovalProcessById(Long id);

    /**
     * 辅导员查看审核列表
     * @param dmsApprovalProcess
     * @return
     */
    List<Map<String, Object>> myApproval(DmsApprovalProcess dmsApprovalProcess);

    /**
     * 辅导员审核换宿申请表
     * @param dmsAuditDto
     * @return
     */
    AjaxResult auditTSSQ(DmsAuditDto dmsAuditDto);

    /**
     * 辅导员审核退宿申请表
     * @param dmsAuditDto
     * @return
     */
    AjaxResult auditOUT(DmsAuditDto dmsAuditDto);

    /**
     * 辅导员审核留宿申请
     * @param dmsAuditDto
     * @return
     */
    AjaxResult auditSTAY(DmsAuditDto dmsAuditDto);

    /**
     * 学务查看申请表
     * @param approvalProcess
     * @return
     */
    List<Map<String, Object>> workApply(DmsApprovalProcess approvalProcess);

    /**
     * 学务审核 调宿申请表
     * @param dmsAuditDto
     * @return
     */
    AjaxResult workAuditTSSQB(DmsAuditDto dmsAuditDto);

    /**
     * 学务审核退宿申请表
     * @param dmsAuditDto
     * @return
     */
    AjaxResult workAuditOUT(DmsAuditDto dmsAuditDto);

    /**
     * 学务审核留宿申请
     * @param dmsAuditDto
     * @return
     */
    AjaxResult workAuditSTay(DmsAuditDto dmsAuditDto);

    /**
     * 学校查看申请记录
     * @param approvalProcess
     * @return
     */
    List<Map<String, Object>> finalApply(DmsApprovalProcess approvalProcess);

    /**
     * 学校审核调宿申请
     * @param dmsAuditDto
     * @return
     */
    AjaxResult finalAuditTSSQB(DmsAuditDto dmsAuditDto);

    /**
     * 学校审核退宿申请表
     * @param dmsAuditDto
     * @return
     */
    AjaxResult finalAuditOUT(DmsAuditDto dmsAuditDto);

    /**
     * 学校审核留宿申请表
     * @param dmsAuditDto
     * @return
     */
    AjaxResult finalAuditSTAY(DmsAuditDto dmsAuditDto);
}
