package com.srs.dormitory.service;

import com.srs.common.core.domain.AjaxResult;
import com.srs.dormitory.domain.DmsDormitoryBed;
import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.dormitory.domain.Dto.BedDto;

import java.util.List;

/**
 * <p>
 * 宿舍床位表 服务类
 * </p>
 *
 * @author 猪油骨
 * @since 2023-07-14
 */
public interface IDmsDormitoryBedService extends IService<DmsDormitoryBed> {

    /**
     * 根据宿舍id查询床位信息
     * @author zhy
     * @date 2023-08-15 10:42:14
     * @param id
     * @return
     **/
    public AjaxResult getBedsByDormId(Long id);

    /***
     * 通过考生号查询宿舍信息
     * @author zhy
     * @date 2023-08-16 16:35:30
     * @param ksh
     * @return
     **/
    public AjaxResult getOwnRoomInfo(String ksh);

    /**
     * 查看床位详细信息
     * @param id 床位id
     * @return
     */
    public AjaxResult getCphDormitoryBedDetail(Long id);

    /**
     * 查看宿舍床位
     * @param id
     * @return
     */
    AjaxResult getCphDormitoryByDormitoryId(Long id);


    /**
     * 修改宿舍床位
     * @param bedDto 请求参数
     * @param username 操作人
     * @return
     */
    AjaxResult updateDmsDormitoryBed(BedDto bedDto, String username);

    /**
     * 添加宿舍床位
     * @param bedDto 请求参数
     * @param username 操作人
     * @return
     */
    AjaxResult addDmsDormitoryBed(BedDto bedDto, String username);

    /**
     * 根据id删除床位
     * @param id
     * @return
     */
    AjaxResult deleteById(Long id);

    /**
     * 批量删除床位
     * @param ids 床位id列表
     * @return
     */
    AjaxResult batchDeleteDormitoryBed(List<Long> ids);
}
