package com.srs.dormitory.service.impl;

import java.util.List;

import com.srs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.srs.dormitory.mapper.DmsCheckLogMapper;
import com.srs.dormitory.domain.DmsCheckLog;
import com.srs.dormitory.service.IDmsCheckLogService;

/**
 * 查寝推送日志Service业务层处理
 *
 * @author srs
 * @date 2024-12-29
 */
@Service
public class DmsCheckLogServiceImpl extends ServiceImpl<DmsCheckLogMapper,DmsCheckLog> implements IDmsCheckLogService {
    @Autowired
    private DmsCheckLogMapper dmsCheckLogMapper;


    @Override
    public List<DmsCheckLog> listView(DmsCheckLog dmsCheckLog){
        return dmsCheckLogMapper.listView(dmsCheckLog);
    }


    /**
     * 查询查寝推送日志
     *
     * @param id 查寝推送日志主键
     * @return 查寝推送日志
     */
    @Override
    public DmsCheckLog selectDmsCheckLogById(Long id) {
        return dmsCheckLogMapper.selectDmsCheckLogById(id);
    }

    /**
     * 查询查寝推送日志列表
     *
     * @param dmsCheckLog 查寝推送日志
     * @return 查寝推送日志
     */
    @Override
    public List<DmsCheckLog> selectDmsCheckLogList(DmsCheckLog dmsCheckLog) {
        return dmsCheckLogMapper.selectDmsCheckLogList(dmsCheckLog);
    }

    /**
     * 新增查寝推送日志
     *
     * @param dmsCheckLog 查寝推送日志
     * @return 结果
     */
    @Override
    public int insertDmsCheckLog(DmsCheckLog dmsCheckLog) {
        dmsCheckLog.setCreateTime(DateUtils.getNowDate());
        return dmsCheckLogMapper.insertDmsCheckLog(dmsCheckLog);
    }

    /**
     * 修改查寝推送日志
     *
     * @param dmsCheckLog 查寝推送日志
     * @return 结果
     */
    @Override
    public int updateDmsCheckLog(DmsCheckLog dmsCheckLog) {
        return dmsCheckLogMapper.updateDmsCheckLog(dmsCheckLog);
    }

    /**
     * 批量删除查寝推送日志
     *
     * @param ids 需要删除的查寝推送日志主键
     * @return 结果
     */
    @Override
    public int deleteDmsCheckLogByIds(Long[] ids) {
        return dmsCheckLogMapper.deleteDmsCheckLogByIds(ids);
    }

    /**
     * 删除查寝推送日志信息
     *
     * @param id 查寝推送日志主键
     * @return 结果
     */
    @Override
    public int deleteDmsCheckLogById(Long id) {
        return dmsCheckLogMapper.deleteDmsCheckLogById(id);
    }
}
