package com.srs.web.controller.staff;

import com.srs.common.annotation.Log;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.core.page.TableDataInfo;
import com.srs.common.enums.BusinessType;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.staff.domain.SysRfile;
import com.srs.staff.service.ISysRfileService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 文件管理Controller
 *
 * @author srs
 * @date 2024-05-16
 */
@RestController
@RequestMapping("/staff/rfile")
@Api(value = "文件管理管理", tags = "文件管理管理")
public class SysRfileController extends BaseController {
    @Autowired
    private ISysRfileService sysRfileService;

    /**
     * 查询文件管理列表
     */
    @PreAuthorize("@ss.hasPermi('staff:rfile:list')")
    @GetMapping("/list")
    @ApiOperation("查询文件管理列表")
    public TableDataInfo list(SysRfile sysRfile) {
        startPage();
        List<SysRfile> list = sysRfileService.selectSysRfileList(sysRfile);
        return getDataTable(list);
    }

    /**
     * 导出文件管理列表
     */
    @PreAuthorize("@ss.hasPermi('staff:rfile:export')")
    @Log(title = "文件管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出文件管理列表")
    public void export(HttpServletResponse response, SysRfile sysRfile) {
        List<SysRfile> list = sysRfileService.selectSysRfileList(sysRfile);
        ExcelUtil<SysRfile> util = new ExcelUtil<SysRfile>(SysRfile.class);
        util.exportExcel(response, list, "文件管理数据");
    }

    /**
     * 获取文件管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('staff:rfile:query')")
    @GetMapping(value = "/{rfileId}")
    @ApiOperation("获取文件管理详细信息")
    public AjaxResult getInfo(@PathVariable("rfileId") Long rfileId) {
        return success(sysRfileService.selectSysRfileByRfileId(rfileId));
    }

    /**
     * 新增文件管理
     */
    @PreAuthorize("@ss.hasPermi('staff:rfile:add')")
    @Log(title = "文件管理", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增文件管理")
    public AjaxResult add(@RequestBody SysRfile sysRfile) {
        return toAjax(sysRfileService.insertSysRfile(sysRfile));
    }

    /**
     * 修改文件管理
     */
    @PreAuthorize("@ss.hasPermi('staff:rfile:edit')")
    @Log(title = "文件管理", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改文件管理")
    public AjaxResult edit(@RequestBody SysRfile sysRfile) {
        return toAjax(sysRfileService.updateSysRfile(sysRfile));
    }

    /**
     * 删除文件管理
     */
    @PreAuthorize("@ss.hasPermi('staff:rfile:remove')")
    @Log(title = "文件管理", businessType = BusinessType.DELETE)
    @PostMapping("/{rfileIds}")
    @ApiOperation("删除文件管理")
    public AjaxResult remove(@PathVariable Long[] rfileIds) {
        return toAjax(sysRfileService.deleteSysRfileByRfileIds(rfileIds));
    }
}
