package com.srs.web.controller.teacher;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.srs.common.annotation.RepeatSubmit;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.teacher.domain.SysTeacherClassMeetingMaterials;
import com.srs.teacher.service.ISysTeacherClassMeetingMaterialsService;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 班会佐证材料Controller
 *
 * @author chc
 * @date 2024-06-05
 */
@RestController
@RequestMapping("/teacher/classMeetingMaterials")
@Api(value = "班会佐证材料管理", tags = "班会佐证材料管理")
public class SysTeacherClassMeetingMaterialsController extends BaseController {
    @Autowired
    private ISysTeacherClassMeetingMaterialsService sysTeacherClassMeetingMaterialsService;

    /**
     * 查询班会佐证材料列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:classMeetingMaterials:list')")
    @GetMapping("/list")
    @ApiOperation("查询班会佐证材料列表")
    public TableDataInfo list(SysTeacherClassMeetingMaterials sysTeacherClassMeetingMaterials) {
        startPage();
        List<SysTeacherClassMeetingMaterials> list = sysTeacherClassMeetingMaterialsService.selectSysTeacherClassMeetingMaterialsList(sysTeacherClassMeetingMaterials);
        return getDataTable(list);
    }

    /**
     * 导出班会佐证材料列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:classMeetingMaterials:export')")
    @Log(title = "班会佐证材料", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出班会佐证材料列表")
    public void export(HttpServletResponse response, SysTeacherClassMeetingMaterials sysTeacherClassMeetingMaterials) {
        List<SysTeacherClassMeetingMaterials> list = sysTeacherClassMeetingMaterialsService.selectSysTeacherClassMeetingMaterialsList(sysTeacherClassMeetingMaterials);
        ExcelUtil<SysTeacherClassMeetingMaterials> util = new ExcelUtil<SysTeacherClassMeetingMaterials>(SysTeacherClassMeetingMaterials.class);
        util.exportExcel(response, list, "班会佐证材料数据");
    }

    /**
     * 获取班会佐证材料详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:classMeetingMaterials:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取班会佐证材料详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sysTeacherClassMeetingMaterialsService.selectSysTeacherClassMeetingMaterialsById(id));
    }

    /**
     * 根据辅导员名称、年份 月份 查询详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:classMeetingMaterials:list')")
    @GetMapping(value = "/getByFdyNameAndYearAndMonth")
    @ApiOperation("根据名称年月获取班会佐证材料列表")
    public TableDataInfo getByFdyNameAndYearAndMonth(@RequestParam String fdyName, @RequestParam String fillingYear, @RequestParam String fillingMonth) {
        startPage();
        List<SysTeacherClassMeetingMaterials> sysTeacherClassMeetingMaterials = sysTeacherClassMeetingMaterialsService.selectSysTeacherClassMeetingMaterialsByFdyName(fdyName, fillingYear, fillingMonth);
        return getDataTable(sysTeacherClassMeetingMaterials);
    }

    /**
     * 新增班会佐证材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:classMeetingMaterials:add')")
    @Log(title = "班会佐证材料", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增班会佐证材料")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult add(@RequestBody SysTeacherClassMeetingMaterials sysTeacherClassMeetingMaterials) {
        return toAjax(sysTeacherClassMeetingMaterialsService.insertSysTeacherClassMeetingMaterials(sysTeacherClassMeetingMaterials));
    }

    /**
     * 修改班会佐证材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:classMeetingMaterials:edit')")
    @Log(title = "班会佐证材料", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改班会佐证材料")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult edit(@RequestBody SysTeacherClassMeetingMaterials sysTeacherClassMeetingMaterials) {
        return toAjax(sysTeacherClassMeetingMaterialsService.updateSysTeacherClassMeetingMaterials(sysTeacherClassMeetingMaterials));
    }

    /**
     * 删除班会佐证材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:classMeetingMaterials:remove')")
    @Log(title = "班会佐证材料", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除班会佐证材料")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sysTeacherClassMeetingMaterialsService.deleteSysTeacherClassMeetingMaterialsByIds(ids));
    }
}
