package com.srs.web.controller.teacher;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.srs.common.annotation.RepeatSubmit;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.teacher.domain.SysTeacherConferenceMeetingMaterials;
import com.srs.teacher.service.ISysTeacherConferenceMeetingMaterialsService;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 业绩考核-个人填报-考勤管理-会议佐证材料Controller
 *
 * @author chc
 * @date 2024-06-11
 */
@RestController
@RequestMapping("/teacher/conferenceMeetingMaterials")
@Api(value = "业绩考核-个人填报-考勤管理-会议佐证材料管理", tags = "业绩考核-个人填报-考勤管理-会议佐证材料管理")
public class SysTeacherConferenceMeetingMaterialsController extends BaseController {
    @Autowired
    private ISysTeacherConferenceMeetingMaterialsService sysTeacherConferenceMeetingMaterialsService;

    /**
     * 查询业绩考核-个人填报-考勤管理-会议佐证材料列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:conferenceMeetingMaterials:list')")
    @GetMapping("/list")
    @ApiOperation("查询业绩考核-个人填报-考勤管理-会议佐证材料列表")
    public TableDataInfo list(SysTeacherConferenceMeetingMaterials sysTeacherConferenceMeetingMaterials) {
        startPage();
        List<SysTeacherConferenceMeetingMaterials> list = sysTeacherConferenceMeetingMaterialsService.selectSysTeacherConferenceMeetingMaterialsList(sysTeacherConferenceMeetingMaterials);
        return getDataTable(list);
    }

    /**
     * 导出业绩考核-个人填报-考勤管理-会议佐证材料列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:conferenceMeetingMaterials:export')")
    @Log(title = "业绩考核-个人填报-考勤管理-会议佐证材料", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出业绩考核-个人填报-考勤管理-会议佐证材料列表")
    public void export(HttpServletResponse response, SysTeacherConferenceMeetingMaterials sysTeacherConferenceMeetingMaterials) {
        List<SysTeacherConferenceMeetingMaterials> list = sysTeacherConferenceMeetingMaterialsService.selectSysTeacherConferenceMeetingMaterialsList(sysTeacherConferenceMeetingMaterials);
        ExcelUtil<SysTeacherConferenceMeetingMaterials> util = new ExcelUtil<SysTeacherConferenceMeetingMaterials>(SysTeacherConferenceMeetingMaterials.class);
        util.exportExcel(response, list, "业绩考核-个人填报-考勤管理-会议佐证材料数据");
    }

    /**
     * 获取业绩考核-个人填报-考勤管理-会议佐证材料详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:conferenceMeetingMaterials:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取业绩考核-个人填报-考勤管理-会议佐证材料详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sysTeacherConferenceMeetingMaterialsService.selectSysTeacherConferenceMeetingMaterialsById(id));
    }

    /**
     * 根据辅导员名称、年份 月份 查询详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:conferenceMeetingMaterials:list')")
    @GetMapping(value = "/getByFdyNameAndYearAndMonth")
    @ApiOperation("根据名称年月获取业绩考核-个人填报-考勤管理-会议佐证材料列表")
    public TableDataInfo getByFdyNameAndYearAndMonth(@RequestParam String fdyName, @RequestParam String fillingYear, @RequestParam String fillingMonth) {
        startPage();
        List<SysTeacherConferenceMeetingMaterials> sysTeacherConferenceMeetingMaterials = sysTeacherConferenceMeetingMaterialsService.selectSysTeacherConferenceMeetingMaterialsByFdyName(fdyName, fillingYear, fillingMonth);
        return getDataTable(sysTeacherConferenceMeetingMaterials);
    }

    /**
     * 新增业绩考核-个人填报-考勤管理-会议佐证材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:conferenceMeetingMaterials:add')")
    @Log(title = "业绩考核-个人填报-考勤管理-会议佐证材料", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增业绩考核-个人填报-考勤管理-会议佐证材料")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult add(@RequestBody SysTeacherConferenceMeetingMaterials sysTeacherConferenceMeetingMaterials) {
        return toAjax(sysTeacherConferenceMeetingMaterialsService.insertSysTeacherConferenceMeetingMaterials(sysTeacherConferenceMeetingMaterials));
    }

    /**
     * 修改业绩考核-个人填报-考勤管理-会议佐证材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:conferenceMeetingMaterials:edit')")
    @Log(title = "业绩考核-个人填报-考勤管理-会议佐证材料", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改业绩考核-个人填报-考勤管理-会议佐证材料")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult edit(@RequestBody SysTeacherConferenceMeetingMaterials sysTeacherConferenceMeetingMaterials) {
        return toAjax(sysTeacherConferenceMeetingMaterialsService.updateSysTeacherConferenceMeetingMaterials(sysTeacherConferenceMeetingMaterials));
    }

    /**
     * 删除业绩考核-个人填报-考勤管理-会议佐证材料
     */
    @PreAuthorize("@ss.hasPermi('teacher:conferenceMeetingMaterials:remove')")
    @Log(title = "业绩考核-个人填报-考勤管理-会议佐证材料", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除业绩考核-个人填报-考勤管理-会议佐证材料")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sysTeacherConferenceMeetingMaterialsService.deleteSysTeacherConferenceMeetingMaterialsByIds(ids));
    }
}
