package com.srs.web.controller.teacher;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.srs.common.annotation.RepeatSubmit;
import com.srs.teacher.domain.SysTeacherConferenceMeetingMaterials;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.teacher.domain.SysTeacherKpiFillingAMgt;
import com.srs.teacher.service.ISysTeacherKpiFillingAMgtService;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 业绩考核-个人填报-考勤管理Controller
 *
 * @author chc
 * @date 2024-06-11
 */
@RestController
@RequestMapping("/teacher/kpiFillingAMgt")
@Api(value = "业绩考核-个人填报-考勤管理", tags = "业绩考核-个人填报-考勤管理")
public class SysTeacherKpiFillingAMgtController extends BaseController {
    @Autowired
    private ISysTeacherKpiFillingAMgtService sysTeacherKpiFillingAMgtService;

    /**
     * 查询业绩考核-个人填报-考勤管理列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingAMgt:list')")
    @GetMapping("/list")
    @ApiOperation("查询业绩考核-个人填报-考勤管理列表")
    public TableDataInfo list(SysTeacherKpiFillingAMgt sysTeacherKpiFillingAMgt) {
        startPage();
        List<SysTeacherKpiFillingAMgt> list = sysTeacherKpiFillingAMgtService.selectSysTeacherKpiFillingAMgtList(sysTeacherKpiFillingAMgt);
        return getDataTable(list);
    }

    /**
     * 根据辅导员名称、年份 月份 查询详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingAMgt:list')")
    @GetMapping(value = "/getByFdyNameAndYearAndMonth")
    @ApiOperation("根据名称年月查询业绩考核-个人填报-考勤管理列表")
    public TableDataInfo getByFdyNameAndYearAndMonth(@RequestParam String fdyName, @RequestParam String fillingYear, @RequestParam String fillingMonth) {
        startPage();
        List<SysTeacherKpiFillingAMgt> sysTeacherKpiFillingAMgtList = sysTeacherKpiFillingAMgtService.selectSysTeacherKpiFillingAMgtByFdyName(fdyName, fillingYear, fillingMonth);
        return getDataTable(sysTeacherKpiFillingAMgtList);
    }

    /**
     * 导出业绩考核-个人填报-考勤管理列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingAMgt:export')")
    @Log(title = "业绩考核-个人填报-考勤管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出业绩考核-个人填报-考勤管理列表")
    public void export(HttpServletResponse response, SysTeacherKpiFillingAMgt sysTeacherKpiFillingAMgt) {
        List<SysTeacherKpiFillingAMgt> list = sysTeacherKpiFillingAMgtService.selectSysTeacherKpiFillingAMgtList(sysTeacherKpiFillingAMgt);
        ExcelUtil<SysTeacherKpiFillingAMgt> util = new ExcelUtil<SysTeacherKpiFillingAMgt>(SysTeacherKpiFillingAMgt.class);
        util.exportExcel(response, list, "业绩考核-个人填报-考勤管理数据");
    }

    /**
     * 获取业绩考核-个人填报-考勤管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingAMgt:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取业绩考核-个人填报-考勤管理详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sysTeacherKpiFillingAMgtService.selectSysTeacherKpiFillingAMgtById(id));
    }

    /**
     * 新增业绩考核-个人填报-考勤管理
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingAMgt:add')")
    @Log(title = "业绩考核-个人填报-考勤管理", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增业绩考核-个人填报-考勤管理")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult add(@RequestBody SysTeacherKpiFillingAMgt sysTeacherKpiFillingAMgt) {
        return toAjax(sysTeacherKpiFillingAMgtService.insertSysTeacherKpiFillingAMgt(sysTeacherKpiFillingAMgt));
    }

    /**
     * 修改业绩考核-个人填报-考勤管理
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingAMgt:edit')")
    @Log(title = "业绩考核-个人填报-考勤管理", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改业绩考核-个人填报-考勤管理")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult edit(@RequestBody SysTeacherKpiFillingAMgt sysTeacherKpiFillingAMgt) {
        return toAjax(sysTeacherKpiFillingAMgtService.updateSysTeacherKpiFillingAMgt(sysTeacherKpiFillingAMgt));
    }

    /**
     * 删除业绩考核-个人填报-考勤管理
     */
    @PreAuthorize("@ss.hasPermi('teacher:kpiFillingAMgt:remove')")
    @Log(title = "业绩考核-个人填报-考勤管理", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除业绩考核-个人填报-考勤管理")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sysTeacherKpiFillingAMgtService.deleteSysTeacherKpiFillingAMgtByIds(ids));
    }
}
