package com.srs.web.controller.teacher;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.srs.common.annotation.RepeatSubmit;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.*;
import org.springframework.security.access.prepost.PreAuthorize;

import com.srs.teacher.domain.SysTeacherKpiFillingStuMgt;
import com.srs.teacher.service.ISysTeacherKpiFillingStuMgtService;
import com.srs.common.core.controller.BaseController;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.utils.poi.ExcelUtil;
import com.srs.common.enums.BusinessType;
import com.srs.common.annotation.Log;
import com.srs.common.core.page.TableDataInfo;

/**
 * 业绩考核-个人填报-学生管理Controller
 *
 * @author chc
 * @date 2024-06-05
 */
@RestController
@RequestMapping("/teacher/teacherKpiFillingMgt")
@Api(value = "业绩考核-个人填报-学生管理管理", tags = "业绩考核-个人填报-学生管理管理")
public class SysTeacherKpiFillingStuMgtController extends BaseController {
    @Autowired
    private ISysTeacherKpiFillingStuMgtService sysTeacherKpiFillingStuMgtService;

    /**
     * 查询业绩考核-个人填报-学生管理列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:teacherKpiFillingMgt:list')")
    @GetMapping("/list")
    @ApiOperation("查询业绩考核-个人填报-学生管理列表")
    public TableDataInfo list(SysTeacherKpiFillingStuMgt sysTeacherKpiFillingStuMgt) {
        startPage();
        List<SysTeacherKpiFillingStuMgt> list = sysTeacherKpiFillingStuMgtService.selectSysTeacherKpiFillingStuMgtList(sysTeacherKpiFillingStuMgt);
        return getDataTable(list);
    }

    /**
     * 根据辅导员名称、年份 月份 查询详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:teacherKpiFillingMgt:query')")
    @GetMapping("/getByFdyNameAndYearAndMonth")
    @ApiOperation("根据名称年月查询业绩考核-个人填报-学生管理详细信息")
    public AjaxResult getByFdyNameAndYearAndMonth(@RequestParam String fdyName, @RequestParam String fillingYear, @RequestParam String fillingMonth) {
        return success(sysTeacherKpiFillingStuMgtService.selectSysTeacherKpiFillingStuMgtByFdyName(fdyName, fillingYear, fillingMonth));
    }

    /**
     * 导出业绩考核-个人填报-学生管理列表
     */
    @PreAuthorize("@ss.hasPermi('teacher:teacherKpiFillingMgt:export')")
    @Log(title = "业绩考核-个人填报-学生管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation("导出业绩考核-个人填报-学生管理列表")
    public void export(HttpServletResponse response, SysTeacherKpiFillingStuMgt sysTeacherKpiFillingStuMgt) {
        List<SysTeacherKpiFillingStuMgt> list = sysTeacherKpiFillingStuMgtService.selectSysTeacherKpiFillingStuMgtList(sysTeacherKpiFillingStuMgt);
        ExcelUtil<SysTeacherKpiFillingStuMgt> util = new ExcelUtil<SysTeacherKpiFillingStuMgt>(SysTeacherKpiFillingStuMgt.class);
        util.exportExcel(response, list, "业绩考核-个人填报-学生管理数据");
    }

    /**
     * 获取业绩考核-个人填报-学生管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('teacher:teacherKpiFillingMgt:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取业绩考核-个人填报-学生管理详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(sysTeacherKpiFillingStuMgtService.selectSysTeacherKpiFillingStuMgtById(id));
    }

    /**
     * 新增业绩考核-个人填报-学生管理
     */
    @PreAuthorize("@ss.hasPermi('teacher:teacherKpiFillingMgt:add')")
    @Log(title = "业绩考核-个人填报-学生管理", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ApiOperation("新增业绩考核-个人填报-学生管理")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult add(@RequestBody SysTeacherKpiFillingStuMgt sysTeacherKpiFillingStuMgt) {
        return toAjax(sysTeacherKpiFillingStuMgtService.insertSysTeacherKpiFillingStuMgt(sysTeacherKpiFillingStuMgt));
    }

    /**
     * 修改业绩考核-个人填报-学生管理
     */
    @PreAuthorize("@ss.hasPermi('teacher:teacherKpiFillingMgt:edit')")
    @Log(title = "业绩考核-个人填报-学生管理", businessType = BusinessType.UPDATE)
    @PostMapping("/update")
    @ApiOperation("修改业绩考核-个人填报-学生管理")
    @RepeatSubmit(interval = 1000, message = "请求过于频繁")
    public AjaxResult edit(@RequestBody SysTeacherKpiFillingStuMgt sysTeacherKpiFillingStuMgt) {
        return toAjax(sysTeacherKpiFillingStuMgtService.updateSysTeacherKpiFillingStuMgt(sysTeacherKpiFillingStuMgt));
    }

    /**
     * 删除业绩考核-个人填报-学生管理
     */
    @PreAuthorize("@ss.hasPermi('teacher:teacherKpiFillingMgt:remove')")
    @Log(title = "业绩考核-个人填报-学生管理", businessType = BusinessType.DELETE)
    @PostMapping("/{ids}")
    @ApiOperation("删除业绩考核-个人填报-学生管理")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(sysTeacherKpiFillingStuMgtService.deleteSysTeacherKpiFillingStuMgtByIds(ids));
    }
}
