package com.srs.comprehensive.service;

import com.srs.common.core.domain.AjaxResult;
import com.srs.comprehensive.domain.CphIam;
import com.srs.comprehensive.domain.CphIdeologyScore;
import com.srs.comprehensive.domain.Vo.CphIamSearchVo;
import com.srs.comprehensive.domain.Vo.CphIamVo;
import com.srs.comprehensive.domain.Vo.CphRecord;
import com.srs.comprehensive.domain.Vo.CphSearch;
import org.springframework.web.bind.annotation.PathVariable;

import java.util.List;
import java.util.Map;

/**
 * 思想品德Service接口
 *
 * @author zhy
 * @date 2023-07-03
 */
public interface ICphIamService {


    public AjaxResult deleteError(Long id);

    List<Map<String, Object>> listErrorAddRecord(CphSearch param);

    public List<CphIamSearchVo> listIamByStuNoYear(CphSearch param);

    public List<CphRecord> getOwnRecord(String stuNo, String year);


    /**
     * 查询思想品德
     *
     * @param id 思想品德主键
     * @return 思想品德
     */
    public CphIam selectCphIamById(Long id);

    /**
     * 查询思想品德列表
     * 
     * @param cphIam 思想品德
     * @return 思想品德集合
     */
    public List<CphIam> selectCphIamList(CphIam cphIam);

    /**
     * 查询思想品德列表 连表查询
     *
     * @param cphIam 思想品德
     * @return 思想品德集合
     */
    public List<CphIam> selectCphIamListJoin(CphIam cphIam);

    /**
     * 查询学生思想品德总分
     * @param cphIam
     * @return
     */
    List<CphIdeologyScore> selectCphIamSumList(CphIdeologyScore cphIam);

    int insertCphIamCounsellor(CphIamVo cphIam);

    /**
     * 新增思想品德
     * 
     * @param cphIam 思想品德
     * @return 结果
     */
    public int insertCphIam(CphIam cphIam);

    /**
     * 修改思想品德
     * 
     * @param cphIam 思想品德
     * @return 结果
     */
    public int updateCphIam(CphIam cphIam);

    /**
     * 批量删除思想品德
     * 
     * @param ids 需要删除的思想品德主键集合
     * @return 结果
     */
    public int deleteCphIamByIds(Long[] ids);

    /**
     * 删除思想品德信息
     * 
     * @param id 思想品德主键
     * @return 结果
     */
    public int deleteCphIamById(Long id);
}
