package com.srs.comprehensive.service;


import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.common.core.domain.AjaxResult;
import com.srs.common.core.domain.entity.SysUser;
import com.srs.comprehensive.domain.Dto.StuDataSelcetDto;
import com.srs.comprehensive.domain.SrsStudent;
import com.srs.comprehensive.domain.Vo.*;
import com.srs.system.domain.vo.StuStatus;

import java.util.List;
import java.util.Map;


/**
 * 学生信息Service接口
 *
 * @author srs
 * @date 2023-06-27
 */
public interface ISrsStudentService extends IService<SrsStudent>
{

    public AjaxResult doDept(CphSearch param);

    public List<Map<String,Object>> countGradeStuNew();

    public List<Map<String,Object>> countDeptStuNew();

    public List<Map<String,Object>> countMajorStuByDept(CphSearch param);

    public List<Map<String,Object>> countDeptGradeStuNew();


    List<StuCount> countParkStu();


    List<StuCount> countLakeGradeStu();

    List<StuCount> countGoodGradeStu();

    List<StuCount> countGoodBiyeGradeStu();

    List<StuCount> countDeptGradeStu();
    List<StuCount> countDeptStu();
    public AjaxResult changeStuInfo( SrsStudent param);

    public SrsStudent getStuInfo(String stuNo);

    /**
     * 查询学生信息
     *
     * @param stuId 学生信息主键
     * @return 学生信息
     */
    public SrsStudent  selectSrsStudentByStuId(Long stuId);

    public List<SrsStudent> listEnableStu();

    public StuClass getOwnClass(String stuNo);
    public  List<StuStatus> statusList();

    /**
     * 查询学生信息列表
     *
     * @param srsStudent 学生信息
     * @return 学生信息集合
     */
    public List<SrsStudent> selectSrsStudentList(SrsStudent srsStudent);
    /**
     * 查询学生信息列表 连表查询
     *
     * @param srsStudent 学生信息
     * @return 学生信息集合
     */
    public List<SrsStudent> selectSrsStudentListJoin(SrsStudent srsStudent);
    /**
     * 通过学号查询信息
     *
     * @param stuNO 学号
     * @return 学生信息
     */
    public SrsStudent selectSrsStudentByStuNo(String stuNO);
    /**
     * 通过班级id查询学生信息
     *
     * @param id 班级id
     * @return 学生信息
     */
    public List<Map<String,Object>>selectSrsStudentNameList(Long id);

    /**
     * 新增学生信息
     *
     * @param srsStudent 学生信息
     * @return 结果
     */
    public int insertSrsStudent(SrsStudent srsStudent);

    /**
     * 修改学生信息
     *
     * @param srsStudent 学生信息
     * @return 结果
     */
    public int updateSrsStudent(SrsStudent srsStudent);

    /**
     * 批量删除学生信息
     *
     * @param stuIds 需要删除的学生信息主键集合
     * @return 结果
     */
    public int deleteSrsStudentByStuIds(Long[] stuIds);

    /**
     * 删除学生信息信息
     *
     * @param stuId 学生信息主键
     * @return 结果
     */
    public int deleteSrsStudentByStuId(Long stuId);
    /**
     *
     * @param stuList 学生信息列表
     * @param operName 操作人
     * @return
     */

    public String importStudent(List<SrsStudent> stuList,  String operName);

    /**
     * 从中间表同步数据
     * @return 结果
     */
    public Map<String, Object> studentDataSync();

    int updateUserPwd(SysUser sysUser);

    int initializePwd();

    List<Map>  sqlserverSynchronousMYSQL(List<Map> mapList);

    //添加学生
    public void addStudentData(List<Map> mapList);

    void Usertb();

    /**
     * 获取学院请假人数
     * @return
     */
    List<DeptLeaveDataVo> getDeptLeveaDataCount();

    /**
     * 根据学号查询辅导员信息
     * @param stuNo
     * @return
     */
    SysUser getTeacherByStuNo(String stuNo);

    /**
     * 查询各学院休学人数
     * @return
     */
    List<DeptStuQuitPunisDataVo> getStuQuitSchoolCount();

    /**
     * 查询各学院处分人数
     * @return
     */
    List<DeptStuQuitPunisDataVo> getStuPunishCount();

    /**
     * 查询各学院困难认定人数
     * @return
     */
    List<DeptStuQuitPunisDataVo> getKnrdCount();

    /**
     * 查询各学院助学金人数
     * @return
     */
    List<DeptStuQuitPunisDataVo> getZxjCount();

    /**
     * 按校区查询学院人数
     * @param campusName
     * @return
     */
    List<DeptStuQuitPunisDataVo> getDeptCountByCampus(String campusName);

    /**
     * 获取在校学生各年级学生人数
     * @return
     */
    List<GradeStuDataVo> getGradeCount();
    /**
     * 获取学院的休学人员具体信息
     * @return
     */
    List<RtStuQuitSchoolVo> getRtStuQuitSchool(StuDataSelcetDto stuDataSelcetDto);
    /**
     * 获取学院的处分人员具体信息
     * @return
     */
    List<RtStuDisciplinaryApplicationVo> getRtStuDisciplinaryApplication(StuDataSelcetDto stuDataSelcetDto);
    /**
     * 获取学院的退学人员具体信息
     * @return
     */
    List<RtStuDropOutSchoolVo> getRtStuDropOutSchool(StuDataSelcetDto stuDataSelcetDto);
    /**
     * 获取学院困难人员具体信息
     */
    List<SrsKnrdApplyVo> getSrsKnrdApply(StuDataSelcetDto stuDataSelcetDto);
    /**
     *获取学院助学金人员具体信息
     * @return
     */
    List<SrsZxjApplyVo> getSrsZxjApply(StuDataSelcetDto stuDataSelcetDto);

    List<DeptStuQuitPunisDataVo> getStuDropOutSchoolCount();

    public List<Map<String,Object>> countStuMZ();

    public  List<Map<String,Object>> getSrsHZCount();

    public  List<Map<String,Object>> getSrsZZCount();

    public  List<Map<String,Object>> getSrsGenderCount();

    public  List<Map<String,Object>> getSrsknrdCount();

    public List<Map<String,Object>> getSrsAgeCount();
    public List<Map<String,Object>> getCountbyCity();
    public List<Map<String,Object>> getSchoolCountbyGrade();
    public List<Map<String,Object>> getSchoolTotalCount();
    public List<Map<String,Object>> getNotSchoolTotalCount();
    public List<Map<String,Object>> getMajorsCount();
    public List<Map<String,Object>> getFiveSchoolTotalCount();
}
