package com.srs.stureg.service.impl;

import java.util.List;
import com.srs.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.srs.stureg.mapper.AtStationMapper;
import com.srs.stureg.domain.AtStation;
import com.srs.stureg.service.IAtStationService;

/**
 * 新生接站登记Service业务层处理
 * 
 * @author 邓
 * @date 2023-05-20
 */
@Service
public class AtStationServiceImpl implements IAtStationService 
{
    @Autowired
    private AtStationMapper atStationMapper;

    /**
     * 查询新生接站登记
     * 
     * @param id 新生接站登记主键
     * @return 新生接站登记
     */
    @Override
    public AtStation selectAtStationById(Long id)
    {
        return atStationMapper.selectAtStationById(id);
    }

    /**
     * 查询新生接站登记
     * @param userId userId
     * @return
     */
    @Override
    public AtStation selectAtStationByUserId(Long userId) {

        return  atStationMapper.selectAtStationByUserId(userId);
    }

    /**
     * 查询新生接站登记列表
     * 
     * @param atStation 新生接站登记
     * @return 新生接站登记
     */
    @Override
    public List<AtStation> selectAtStationList(AtStation atStation)
    {
        return atStationMapper.selectAtStationList(atStation);
    }

    /**
     * 新增新生接站登记
     * 
     * @param atStation 新生接站登记
     * @return 结果
     */
    @Override
    public int insertAtStation(AtStation atStation)
    {
        atStation.setCreateTime(DateUtils.getNowDate());
        return atStationMapper.insertAtStation(atStation);
    }

    /**
     * 修改新生接站登记
     * 
     * @param atStation 新生接站登记
     * @return 结果
     */
    @Override
    public int updateAtStation(AtStation atStation)
    {
        atStation.setUpdateTime(DateUtils.getNowDate());
        return atStationMapper.updateAtStation(atStation);
    }

    /**
     * 批量删除新生接站登记
     * 
     * @param ids 需要删除的新生接站登记主键
     * @return 结果
     */
    @Override
    public int deleteAtStationByIds(Long[] ids)
    {
        return atStationMapper.deleteAtStationByIds(ids);
    }

    /**
     * 删除新生接站登记信息
     * 
     * @param id 新生接站登记主键
     * @return 结果
     */
    @Override
    public int deleteAtStationById(Long id)
    {
        return atStationMapper.deleteAtStationById(id);
    }
}
