package com.srs.teacher.domain;

import java.util.Date;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.srs.common.annotation.Excel;
import com.baomidou.mybatisplus.annotation.*;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.*;
import com.srs.common.core.domain.BaseEntity;

import javax.validation.constraints.NotNull;


/**
 * 学生开展活动佐证材料对象 sys_teacher_stu_activity_materials
 *
 * @author chc
 * @date 2024-06-06
 */
@Data
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@AllArgsConstructor
@Builder
@ApiModel(value = "SysTeacherStuActivityMaterials对象", description = "学生开展活动表佐证材料表")
@TableName("sys_teacher_stu_activity_materials")
public class SysTeacherStuActivityMaterials extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 学生开展活动id
     */
    @ApiModelProperty("学生开展活动id")
    @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 开展时间
     */
    @ApiModelProperty("开展时间")
    @TableField("development_time")
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "开展时间", width = 30, dateFormat = "yyyy-MM-dd")
    private Date developmentTime;

    /**
     * 地点
     */
    @ApiModelProperty("地点")
    @TableField("place")
    @Excel(name = "地点")
    private String place;

    /**
     * 班级名称
     */
    @ApiModelProperty("班级名称")
    @TableField("class_name")
    @Excel(name = "班级名称")
    private String className;

    /**
     * 参与学生人数
     */
    @ApiModelProperty("参与学生人数")
    @TableField("number_of_students")
    @Excel(name = "参与学生人数")
    private Long numberOfStudents;

    /**
     * 主要内容
     */
    @ApiModelProperty("主要内容")
    @TableField("main_content")
    @Excel(name = "主要内容")
    private String mainContent;

    /**
     * 相片
     */
    @ApiModelProperty("相片")
    @TableField("photo")
    @Excel(name = "相片")
    private String photo;

    /**
     * 填报人名称
     */
    @ApiModelProperty(value = "填报人名称", required = true)
    @TableField("fdy_name")
    @Excel(name = "填报人名称")
    private String fdyName;

    /**
     * 填报年份
     */
    @ApiModelProperty(value = "填报年份", required = true)
    @TableField("filling_year")
    @Excel(name = "填报年份")
    private String fillingYear;

    /**
     * 填报月份
     */
    @ApiModelProperty(value = "填报月份", required = true)
    @TableField("filling_month")
    @Excel(name = "填报月份")
    @NotNull(message = "填报月份不能为空")
    private String fillingMonth;


}
