package com.srs.workstudy.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.srs.common.annotation.Excel;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 勤工助学工作记录对象 qgzx_work_log
 *
 * @author srs
 * @date 2024-06-11
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@Builder
@ApiModel(value = "QgzxWorkLog对象", description = "勤工助学工作记录")
@TableName("qgzx_work_log")
public class QgzxWorkLog {
    private static final long serialVersionUID = 1L;


    @TableField(exist = false)
    public String stuNo;

    @TableField(exist = false)
    public String stuName;

    @TableField(exist = false)
    public String stuDept;

    @TableField(exist = false)
    public String deptCode;

    @TableField(exist = false)
    public String deptName;

    @TableField(exist = false)
    public String postName;


    @TableField(exist = false)
    public String zdlsName;


    @TableField(exist = false)
    public String zdlsNo;


    /**
     * #
     */
    @ApiModelProperty("#")
    @TableId(value = "id", type = IdType.AUTO)
    public Long id;

    /**
     * 学生岗位id
     */
    @ApiModelProperty("学生岗位id")
    @TableField("stu_post_id")
    @Excel(name = "学生岗位id")
    public Long stuPostId;

    /**
     * 工作时长
     */
    @ApiModelProperty("工作时长")
    @TableField("work_time")
    @Excel(name = "工作时长")
    public BigDecimal workTime;

    /**
     * 主要工作
     */
    @ApiModelProperty("主要工作")
    @TableField("main_work")
    @Excel(name = "主要工作")
    public String mainWork;

    /**
     * 工作附件
     */
    @ApiModelProperty("工作附件")
    @TableField("work_material")
    @Excel(name = "工作附件")
    public String workMaterial;

    /**
     * 工作日期
     */
    @ApiModelProperty("工作日期")
    @TableField("work_date")
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "工作日期", width = 30, dateFormat = "yyyy-MM-dd")
    public Date workDate;

    /**
     * 申请时间
     */
    @ApiModelProperty("申请时间")
    @TableField("apply_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "申请时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    public Date applyTime;

    /**
     * 审核状态
     */
    @ApiModelProperty("审核状态，字典：qgzx_apply_status")
    @TableField("apply_status")
    @Excel(name = "审核状态")
    public String applyStatus;

    /**
     * 指导老师意见
     */
    @ApiModelProperty("指导老师意见")
    @TableField("zdls_cmt")
    @Excel(name = "指导老师意见")
    public String zdlsCmt;


    /**
     * 指导老师签章
     */
    @ApiModelProperty("指导老师签章")
    @TableField("zdls_sign")
    @Excel(name = "指导老师签章")
    public String zdlsSign;

    @TableField(exist = false)
    public Date workMonth;

    @TableField(exist = false)
    public String postType;

    @ApiModelProperty("指导老师审核时间")
    @TableField("zdls_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    public Date zdlsTime;


}
